package jp.hamachi.android.demo.lock;

import android.app.KeyguardManager;
import android.content.Context;
import android.content.SharedPreferences;
import android.graphics.PixelFormat;
import android.preference.PreferenceManager;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.WindowManager;
import android.view.WindowManager.LayoutParams;

public class LockUtil implements OnClickListener{

	// めんどいからシングルトン
	private static LockUtil instance = new LockUtil();
	
	private LockUtil(){
	}
	
	public static LockUtil getInstance(){
		return instance;
	}
	
	// ロック画面用
	private View mLockView = null;
	private WindowManager mWindowManager = null;
	
	
	public void lock( Context _c ){
		
		// 設定値を取得
		SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(_c);
		boolean isEnabled = sp.getBoolean("is_enabled", false);
		
		if ( isEnabled ){
			// ロック有効の場合
			
			// ロック画面を作って
			mLockView = LayoutInflater.from(_c).inflate(R.layout.lock, null);
			// ボタン押下時のリスナーを設定
			mLockView.findViewById(R.id.button_unlock).setOnClickListener(this);

			// android.view.WindowManager.LayoutParams
			// ロック画面表示用のパラメータ
			LayoutParams params = new LayoutParams();
			
			// 全画面
			params.width = LayoutParams.FILL_PARENT;
			params.height = LayoutParams.FILL_PARENT;
			// SystemAlert
			params.type = LayoutParams.TYPE_SYSTEM_ALERT;
			// 透過
			params.format = PixelFormat.TRANSLUCENT;
			// 裏はぼやける
			params.flags = LayoutParams.FLAG_BLUR_BEHIND;
			
			// WindowManagerに追加
			if ( mWindowManager == null ){
				mWindowManager = (WindowManager)_c.getSystemService(Context.WINDOW_SERVICE);
			}
			mWindowManager.addView(mLockView, params);
			
		}else{
			// ロックが無効
		}
	}
	
	public void unlock(){
		// WindowManagerから削除
		mWindowManager.removeView(mLockView);
	}
	
	@Override
	public void onClick(View v) {
		switch ( v.getId() ){
		case R.id.button_unlock:
			// 解除ボタン押下時、解除処理を呼ぶ
			unlock();
		}
	}
	
	// キーガード用
	private KeyguardManager mKeyguard = null;
	private KeyguardManager.KeyguardLock mLock = null;
	
	public void disableKeyguard( Context _c ){
		
		// 初期化して
		if ( mKeyguard == null ){
			mKeyguard = (KeyguardManager)_c.getSystemService(Context.KEYGUARD_SERVICE);
			mLock = mKeyguard.newKeyguardLock("LockUtil");
		}
		
		// キーガードを無効化
		mLock.disableKeyguard();
		
	}
	
	public void enableKeyguard(){
		// キーガードを有効化
		if ( mLock != null ){
			mLock.reenableKeyguard();
		}else{
			// nullの場合は無効化されて無い
		}
		
	}

}
